@@ -9,9 +9,12 @@ where
 import Common
 import Control.Exception (bracket)
 import Sqlite qualified as DS
+import Test.Tasty.HUnit
+import Test.Tasty.HUnit qualified as Tasty
 
-testDirectSqlite :: TestEnv -> Test
-testDirectSqlite TestEnv {..} = TestCase $ do
+testDirectSqlite :: IO TestEnv -> Tasty.Assertion
+testDirectSqlite ioenv = do
+  TestEnv {..} <- ioenv
   let dsConn = conn
   bracket (DS.prepare dsConn "SELECT 1+1") DS.finalize testDirect
   [MkSolo (res :: Int)] <- select_ conn "SELECT 1+2"
